Event Index — Poezio 0.9-dev documentation

# Event Index

The following events are poezio-only events, for Slixmpp events, check out their index.

changing_nick
  - presence: `Presence` to be sent

  Triggered when the user changes his/her nickname on a MUC. The presence can thus be modified before being sent.

conversation_chatstate
  - message: `Message` received
  - tab: `ConversationTab` source

  Triggered when a chatstate is received in a `ConversationTab`.

conversation_msg
  - message: `Message` received
  - tab: `ConversationTab` source

  Triggered when a message is received in a `ConversationTab`.

conversation_say
  - message: `Message` that will be sent
  - tab: `ConversationTab` source

  Triggered whenever the user sends a message to a `ConversationTab`.

conversation_say_after:
  - message: `Message` that will be sent
  - tab: `ConversationTab` source

  Same thing than conversation_say, but after XHTML generation of the body, if needed. This means you must not insert any colors in the body in the handler, since it may lead to send invalid XML. This hook is less safe than conversation_say and you should probably not need it.

ignored_private
  - message `Message` received
  - tab: `PrivateTab` source

  Triggered when a private message (that goes in a `PrivateTab`) is ignored automatically by poezio.

  tab is always `None`, except when a tab has already been
    opened.
joining_muc
  - presence: `Presence` to be sent

  Triggered when joining a MUC. The presence can thus be modified before being sent.

muc_ban
  - presence: `Presence` received
  - tab: `MucTab` source

  Triggered when an user from a `MucTab` gets banned.

muc_chatstate
  - message: `Message` received
  - tab: `MucTab` source

  Triggered when a chatstate is received in a `MucTab`.

muc_join
  - presence: `Presence` received
  - tab: `MucTab` source

  Triggered when an user joins a `MucTab`

muc_kicked
  - presence: `Presence` received
  - tab: `MucTab` source

  Triggered when an user from a `MucTab` gets kicked.

muc_msg
  - message: `Message` received
  - tab: `MucTab` source

  Triggered when a message is received in a `MucTab`.

muc_nickchange
  - presence: `Presence` received
  - tab: `MucTab` source

  Triggered when an user in a `MucTab` changes his nickname.

muc_presence
  - presence: `Presence` received
  - tab: `MucTab` source

  Triggered when a presence is received from someone in a `MucTab`.

muc_say
  - message: `Message` that will be sent
  - tab: `MucTab` source

  Triggered whenever the user sends a message to a `MucTab`.

muc_say_after
  - message: `Message` that will be sent
  - tab: `MucTab` source

  Same thing than muc_say, but after XHTML generation of the body, if needed. This means you must not insert any colors in the body in the handler, since it may lead to send invalid XML. This hook is less safe than `muc_say` and you should probably not need it.

normal_presence
  - presence: `Presence` received
  - resource: `Resource` that emitted the `Presence`

  Triggered when a presence is received from a contact.

private_chatstate
  - message: `Message` received
  - tab: `PrivateTab` source

  Triggered when a chatstate is received in a `PrivateTab`.

private_msg
  - message: `Message` received
  - tab: `PrivateTab` source

  Triggered when a message is received in a `PrivateTab`.

private_say
  - message: `Message` that will be sent
  - tab: `PrivateTab` source

  Triggered whenever the user sends a message to a `PrivateTab`.

private_say_after
  - message: `Message` that will be sent
  - tab: `PrivateTab` source

  Same thing than private_say, but after XHTML generation of the body, if needed. This means you must not insert any colors in the body in the handler, since it may lead to send invalid XML. This hook is less safe than private_say and you should probably not need it.

send_normal_presence
  - presence: `Presence` sent

  Triggered when poezio sends a new `Presence` stanza. The presence can thus be modified before being sent.

tab_change
  - old_tab_nb: `int` Old current tab number.
  - new_tab_nb: `int` New current tab number.

  Triggered whenever the user switches between tabs.